@@ -1022,7 +1022,7 @@ where
     fn emit_bin_value(&mut self, n: &BinValue) -> Result {
         emit!(self, n.left);
 
-        let need_space = matches!(n.op, BinOp::Add | BinOp::Mul);
+        let need_space = matches!(n.op, BinOp::Add | BinOp::Sub);
 
         if need_space {
             space!(self);
@@ -1101,11 +1101,15 @@ where
                 Token::Url {
                     raw_name,
                     raw_value,
+                    before,
+                    after,
                     ..
                 } => {
                     self.wr.write_raw(None, raw_name)?;
                     punct!(self, "(");
+                    self.wr.write_raw(None, before)?;
                     self.wr.write_raw(None, raw_value)?;
+                    self.wr.write_raw(None, after)?;
                     punct!(self, ")");
                 }
                 Token::BadUrl {
@@ -1179,7 +1183,19 @@ where
 
     #[emitter]
     fn emit_url_value_raw(&mut self, n: &UrlValueRaw) -> Result {
-        self.wr.write_raw(Some(n.span), &n.raw)?;
+        if !self.config.minify {
+            self.wr.write_raw(Some(n.span), &n.before)?;
+        }
+
+        if self.config.minify {
+            self.wr.write_raw(Some(n.span), &n.value)?;
+        } else {
+            self.wr.write_raw(Some(n.span), &n.raw)?;
+        }
+
+        if !self.config.minify {
+            self.wr.write_raw(Some(n.span), &n.after)?;
+        }
     }
 
     #[emitter]
